# Table of Contents

- [apptio-technical-overview](<./apptio-technical-overview.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Apptio Technical Overview](<./Apptio-Technical-Overview.md>)
  - [Configure the Integration in SAP LeanIX](<./Apptio-Technical-Overview/Configure-the-Integration-in-SAP-LeanIX.md>)
  - [Apptio Endpoints](<./Apptio-Technical-Overview/Apptio-Endpoints.md>)
  - [View the Integration Status](<./Apptio-Technical-Overview/View-the-Integration-Status.md>)
